@@ -197,7 +197,7 @@ class ChromeRemoteDebugInterface(ChromeRemoteDebugInterface_base):
 		#       json.c_str());
 
 		if args or should_call:
-			expression = "({script}).apply(null, {args})".format(
+			expression = "({script}).apply(null, JSON.parse({args}))".format(
 					script=script,
 					args=json.dumps(args)
 				)
